"""Raw representations of every data type in the AWS IoTEvents service.

See Also:
    `AWS developer guide for IoTEvents
    <https://docs.aws.amazon.com/iotevents/latest/developerguide/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = ["DetectorModel", "DetectorModelProperties", "Input", "InputProperties"]


@attrs(**ATTRSCONFIG)
class DetectorModelProperties(ResourceProperties):
    DetectorModelDefinition = attrib(default=None)
    DetectorModelDescription = attrib(default=None)
    DetectorModelName = attrib(default=None)
    Key = attrib(default=None)
    RoleArn = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class DetectorModel(Resource):
    """A Detector Model for IoTEvents.

    See Also:
        `AWS Cloud Formation documentation for DetectorModel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotevents-detectormodel.html>`_
    """

    RESOURCE_TYPE = "AWS::IoTEvents::DetectorModel"

    Properties: DetectorModelProperties = attrib(
        factory=DetectorModelProperties,
        converter=create_object_converter(DetectorModelProperties),
    )


@attrs(**ATTRSCONFIG)
class InputProperties(ResourceProperties):
    InputDefinition = attrib(default=None)
    InputDescription = attrib(default=None)
    InputName = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Input(Resource):
    """A Input for IoTEvents.

    See Also:
        `AWS Cloud Formation documentation for Input
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iotevents-input.html>`_
    """

    RESOURCE_TYPE = "AWS::IoTEvents::Input"

    Properties: InputProperties = attrib(
        factory=InputProperties, converter=create_object_converter(InputProperties)
    )



"""Raw representations of every data type in the AWS PinpointEmail service.

See Also:
    `AWS developer guide for PinpointEmail
    <http://docs.aws.amazon.com/pinpoint/latest/userguide/welcome.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "ConfigurationSet",
    "ConfigurationSetProperties",
    "ConfigurationSetEventDestination",
    "ConfigurationSetEventDestinationProperties",
    "DedicatedIpPool",
    "DedicatedIpPoolProperties",
    "Identity",
    "IdentityProperties",
]


@attrs(**ATTRSCONFIG)
class ConfigurationSetProperties(ResourceProperties):
    DeliveryOptions = attrib(default=None)
    Name = attrib(default=None)
    ReputationOptions = attrib(default=None)
    SendingOptions = attrib(default=None)
    Tags = attrib(default=None)
    TrackingOptions = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ConfigurationSet(Resource):
    """A Configuration Set for PinpointEmail.

    See Also:
        `AWS Cloud Formation documentation for ConfigurationSet
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpointemail-configurationset.html>`_
    """

    RESOURCE_TYPE = "AWS::PinpointEmail::ConfigurationSet"

    Properties: ConfigurationSetProperties = attrib(
        factory=ConfigurationSetProperties,
        converter=create_object_converter(ConfigurationSetProperties),
    )


@attrs(**ATTRSCONFIG)
class ConfigurationSetEventDestinationProperties(ResourceProperties):
    ConfigurationSetName = attrib(default=None)
    EventDestination = attrib(default=None)
    EventDestinationName = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ConfigurationSetEventDestination(Resource):
    """A Configuration Set Event Destination for PinpointEmail.

    See Also:
        `AWS Cloud Formation documentation for ConfigurationSetEventDestination
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpointemail-configurationseteventdestination.html>`_
    """

    RESOURCE_TYPE = "AWS::PinpointEmail::ConfigurationSetEventDestination"

    Properties: ConfigurationSetEventDestinationProperties = attrib(
        factory=ConfigurationSetEventDestinationProperties,
        converter=create_object_converter(ConfigurationSetEventDestinationProperties),
    )


@attrs(**ATTRSCONFIG)
class DedicatedIpPoolProperties(ResourceProperties):
    PoolName = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class DedicatedIpPool(Resource):
    """A Dedicated Ip Pool for PinpointEmail.

    See Also:
        `AWS Cloud Formation documentation for DedicatedIpPool
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpointemail-dedicatedippool.html>`_
    """

    RESOURCE_TYPE = "AWS::PinpointEmail::DedicatedIpPool"

    Properties: DedicatedIpPoolProperties = attrib(
        factory=DedicatedIpPoolProperties,
        converter=create_object_converter(DedicatedIpPoolProperties),
    )


@attrs(**ATTRSCONFIG)
class IdentityProperties(ResourceProperties):
    DkimSigningEnabled = attrib(default=None)
    FeedbackForwardingEnabled = attrib(default=None)
    MailFromAttributes = attrib(default=None)
    Name = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Identity(Resource):
    """A Identity for PinpointEmail.

    See Also:
        `AWS Cloud Formation documentation for Identity
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpointemail-identity.html>`_
    """

    RESOURCE_TYPE = "AWS::PinpointEmail::Identity"

    Properties: IdentityProperties = attrib(
        factory=IdentityProperties,
        converter=create_object_converter(IdentityProperties),
    )



"""General-use classes to interact with the AppMesh service through CloudFormation.

See Also:
    `AWS developer guide for AppMesh
    <https://docs.aws.amazon.com/app-mesh/?id=docs_gateway>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import appmesh as _raw

# noinspection PyUnresolvedReferences
from .._raw.appmesh import *



"""Raw representations of every data type in the AWS Backup service.

See Also:
    `AWS developer guide for Backup
    <https://docs.aws.amazon.com/aws-backup/latest/devguide/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "BackupPlan",
    "BackupPlanProperties",
    "BackupSelection",
    "BackupSelectionProperties",
    "BackupVault",
    "BackupVaultProperties",
]


@attrs(**ATTRSCONFIG)
class BackupPlanProperties(ResourceProperties):
    BackupPlan = attrib(default=None)
    BackupPlanTags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class BackupPlan(Resource):
    """A Backup Plan for Backup.

    See Also:
        `AWS Cloud Formation documentation for BackupPlan
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-backup-backupplan.html>`_
    """

    RESOURCE_TYPE = "AWS::Backup::BackupPlan"

    Properties: BackupPlanProperties = attrib(
        factory=BackupPlanProperties,
        converter=create_object_converter(BackupPlanProperties),
    )


@attrs(**ATTRSCONFIG)
class BackupSelectionProperties(ResourceProperties):
    BackupPlanId = attrib(default=None)
    BackupSelection = attrib(default=None)


@attrs(**ATTRSCONFIG)
class BackupSelection(Resource):
    """A Backup Selection for Backup.

    See Also:
        `AWS Cloud Formation documentation for BackupSelection
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-backup-backupselection.html>`_
    """

    RESOURCE_TYPE = "AWS::Backup::BackupSelection"

    Properties: BackupSelectionProperties = attrib(
        factory=BackupSelectionProperties,
        converter=create_object_converter(BackupSelectionProperties),
    )


@attrs(**ATTRSCONFIG)
class BackupVaultProperties(ResourceProperties):
    AccessPolicy = attrib(default=None)
    BackupVaultName = attrib(default=None)
    BackupVaultTags = attrib(default=None)
    EncryptionKeyArn = attrib(default=None)
    Notifications = attrib(default=None)


@attrs(**ATTRSCONFIG)
class BackupVault(Resource):
    """A Backup Vault for Backup.

    See Also:
        `AWS Cloud Formation documentation for BackupVault
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-backup-backupvault.html>`_
    """

    RESOURCE_TYPE = "AWS::Backup::BackupVault"

    Properties: BackupVaultProperties = attrib(
        factory=BackupVaultProperties,
        converter=create_object_converter(BackupVaultProperties),
    )



"""Raw representations of every data type in the AWS AppMesh service.

See Also:
    `AWS developer guide for AppMesh
    <https://docs.aws.amazon.com/app-mesh/?id=docs_gateway>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "Mesh",
    "MeshProperties",
    "Route",
    "RouteProperties",
    "VirtualNode",
    "VirtualNodeProperties",
    "VirtualRouter",
    "VirtualRouterProperties",
    "VirtualService",
    "VirtualServiceProperties",
]


@attrs(**ATTRSCONFIG)
class MeshProperties(ResourceProperties):
    MeshName = attrib(default=None)
    Spec = attrib(default=None)
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Mesh(Resource):
    """A Mesh for AppMesh.

    See Also:
        `AWS Cloud Formation documentation for Mesh
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appmesh-mesh.html>`_
    """

    RESOURCE_TYPE = "AWS::AppMesh::Mesh"

    Properties: MeshProperties = attrib(
        factory=MeshProperties, converter=create_object_converter(MeshProperties)
    )


@attrs(**ATTRSCONFIG)
class RouteProperties(ResourceProperties):
    MeshName = attrib(default=None)
    RouteName = attrib(default=None)
    Spec = attrib(default=None)
    Tags = attrib(default=None)
    VirtualRouterName = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Route(Resource):
    """A Route for AppMesh.

    See Also:
        `AWS Cloud Formation documentation for Route
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appmesh-route.html>`_
    """

    RESOURCE_TYPE = "AWS::AppMesh::Route"

    Properties: RouteProperties = attrib(
        factory=RouteProperties, converter=create_object_converter(RouteProperties)
    )


@attrs(**ATTRSCONFIG)
class VirtualNodeProperties(ResourceProperties):
    MeshName = attrib(default=None)
    Spec = attrib(default=None)
    Tags = attrib(default=None)
    VirtualNodeName = attrib(default=None)


@attrs(**ATTRSCONFIG)
class VirtualNode(Resource):
    """A Virtual Node for AppMesh.

    See Also:
        `AWS Cloud Formation documentation for VirtualNode
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appmesh-virtualnode.html>`_
    """

    RESOURCE_TYPE = "AWS::AppMesh::VirtualNode"

    Properties: VirtualNodeProperties = attrib(
        factory=VirtualNodeProperties,
        converter=create_object_converter(VirtualNodeProperties),
    )


@attrs(**ATTRSCONFIG)
class VirtualRouterProperties(ResourceProperties):
    MeshName = attrib(default=None)
    Spec = attrib(default=None)
    Tags = attrib(default=None)
    VirtualRouterName = attrib(default=None)


@attrs(**ATTRSCONFIG)
class VirtualRouter(Resource):
    """A Virtual Router for AppMesh.

    See Also:
        `AWS Cloud Formation documentation for VirtualRouter
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appmesh-virtualrouter.html>`_
    """

    RESOURCE_TYPE = "AWS::AppMesh::VirtualRouter"

    Properties: VirtualRouterProperties = attrib(
        factory=VirtualRouterProperties,
        converter=create_object_converter(VirtualRouterProperties),
    )


@attrs(**ATTRSCONFIG)
class VirtualServiceProperties(ResourceProperties):
    MeshName = attrib(default=None)
    Spec = attrib(default=None)
    Tags = attrib(default=None)
    VirtualServiceName = attrib(default=None)


@attrs(**ATTRSCONFIG)
class VirtualService(Resource):
    """A Virtual Service for AppMesh.

    See Also:
        `AWS Cloud Formation documentation for VirtualService
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appmesh-virtualservice.html>`_
    """

    RESOURCE_TYPE = "AWS::AppMesh::VirtualService"

    Properties: VirtualServiceProperties = attrib(
        factory=VirtualServiceProperties,
        converter=create_object_converter(VirtualServiceProperties),
    )



"""General-use classes to interact with the MediaStore service through CloudFormation.

See Also:
    `AWS developer guide for MediaStore
    <https://docs.aws.amazon.com/mediastore/latest/ug/what-is.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import mediastore as _raw

# noinspection PyUnresolvedReferences
from .._raw.mediastore import *



"""Raw representations of every data type in the AWS LakeFormation service.

See Also:
    `AWS developer guide for LakeFormation
    <https://docs.aws.amazon.com/lake-formation/latest/dg/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "DataLakeSettings",
    "DataLakeSettingsProperties",
    "Permissions",
    "PermissionsProperties",
    "Resource",
    "ResourceProperties",
]


@attrs(**ATTRSCONFIG)
class DataLakeSettingsProperties(ResourceProperties):
    Admins = attrib(default=None)


@attrs(**ATTRSCONFIG)
class DataLakeSettings(Resource):
    """A Data Lake Settings for LakeFormation.

    See Also:
        `AWS Cloud Formation documentation for DataLakeSettings
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-datalakesettings.html>`_
    """

    RESOURCE_TYPE = "AWS::LakeFormation::DataLakeSettings"

    Properties: DataLakeSettingsProperties = attrib(
        factory=DataLakeSettingsProperties,
        converter=create_object_converter(DataLakeSettingsProperties),
    )


@attrs(**ATTRSCONFIG)
class PermissionsProperties(ResourceProperties):
    DataLakePrincipal = attrib(default=None)
    Permissions = attrib(default=None)
    PermissionsWithGrantOption = attrib(default=None)
    Resource = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Permissions(Resource):
    """A Permissions for LakeFormation.

    See Also:
        `AWS Cloud Formation documentation for Permissions
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-permissions.html>`_
    """

    RESOURCE_TYPE = "AWS::LakeFormation::Permissions"

    Properties: PermissionsProperties = attrib(
        factory=PermissionsProperties,
        converter=create_object_converter(PermissionsProperties),
    )


@attrs(**ATTRSCONFIG)
class ResourceProperties(ResourceProperties):
    ResourceArn = attrib(default=None)
    RoleArn = attrib(default=None)
    UseServiceLinkedRole = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Resource(Resource):
    """A Resource for LakeFormation.

    See Also:
        `AWS Cloud Formation documentation for Resource
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lakeformation-resource.html>`_
    """

    RESOURCE_TYPE = "AWS::LakeFormation::Resource"

    Properties: ResourceProperties = attrib(
        factory=ResourceProperties,
        converter=create_object_converter(ResourceProperties),
    )



"""General-use classes to interact with the Amplify service through CloudFormation.

See Also:
    `AWS developer guide for Amplify
    <https://docs.aws.amazon.com/amplify/latest/userguide/getting-started.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import amplify as _raw

# noinspection PyUnresolvedReferences
from .._raw.amplify import *



"""General-use classes to interact with the Pinpoint service through CloudFormation.

See Also:
    `AWS developer guide for Pinpoint
    <https://docs.aws.amazon.com/pinpoint/latest/userguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import pinpoint as _raw

# noinspection PyUnresolvedReferences
from .._raw.pinpoint import *



"""General-use classes to interact with the ManagedBlockchain service through CloudFormation.

See Also:
    `AWS developer guide for ManagedBlockchain
    <https://docs.aws.amazon.com/managed-blockchain/latest/managementguide>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import managedblockchain as _raw

# noinspection PyUnresolvedReferences
from .._raw.managedblockchain import *
